@@ -222,7 +222,8 @@ class Template_List_Dialog(QDialog, Ui_Template_Dialog):
                                               'exists already.  '
                                               'Would you like to replace '
                                               'that template?' % new_name,
-                                              'Replace', 'Cancel')
+                                              QMessageBox.Yes,
+                                              QMessageBox.Cancel)
                 if choice == 1:
                     return	# let user correct name
             else:
