@@ -60,11 +60,11 @@ class Credentials_Dialog(QDialog, Ui_Credentials_Dialog):
             self.prompt_label.setText(prompt)
         self.username_lineEdit.setFocus()
 
-    def exec(self):
+    def exec_(self):
         self.accepted = False
         self.username = None
         self.password = None
-        super().exec()
+        super().exec_()
 
     def accept(self):
         super().accept()
@@ -226,7 +226,7 @@ class Manager(sn.Manager):
 
     def _ask_credentials(self):
         dialog = Credentials_Dialog(self.ui, self.previous_login_failed)
-        dialog.exec()
+        dialog.exec_()
         if not dialog.accepted:
             raise LoginCanceled()
         return [dialog.username, dialog.password]
